#ifndef CONF_USER_H
#define CONF_USER_H

#define CONF_USERO "root" /* owner of miscellaneous files; e.g., binaries */

#define CONF_USERA "alias"
#define CONF_USERD "qmaild"
#define CONF_USERL "qmaill"
#define CONF_USERP "qmailp"
#define CONF_USERQ "qmailq"
#define CONF_USERR "qmailr"
#define CONF_USERS "qmails"

#define CONF_GROUPQ "qmail"

#define CONF_GROUPX "nofiles" /* powerless group */

#endif
